@@ -1,18 +1,23 @@
 """Test for libtmux Session object."""
 
+from __future__ import annotations
+
 import logging
 import shutil
+import typing as t
 
 import pytest
 
 from libtmux import exc
 from libtmux.common import has_gte_version, has_lt_version
 from libtmux.pane import Pane
-from libtmux.server import Server
 from libtmux.session import Session
 from libtmux.test import TEST_SESSION_PREFIX, namer
 from libtmux.window import Window
 
+if t.TYPE_CHECKING:
+    from libtmux.server import Server
+
 logger = logging.getLogger(__name__)
 
 
@@ -309,6 +314,6 @@ def test_new_window_with_environment_logs_warning_for_old_tmux(
         environment={"ENV_VAR": "window"},
     )
 
-    assert any(
-        "Environment flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Environment flag ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
